@@ -366,19 +366,6 @@ void QXmppClient::connectToServer(const QString& host,
 
 bool QXmppClient::sendPacket(const QXmppPacket& packet)
 {
-    // Try to cast the packet to Presence packet, and if that succeeds, call the
-    // addProperCapability() on it and send the result, otherwise, if the cast would
-    // fail, the usual sendPacket() would be called.
-    try
-    {
-        // Construct a copy, cause the source parameter is const ref.
-        QXmppPresence pres = dynamic_cast<const QXmppPresence&>(packet);
-        addProperCapability(pres);
-        return d->stream->sendPacket(pres);
-    }
-    catch (...)
-    {
-    }
     return d->stream->sendPacket(packet);
 }
 
@@ -489,21 +476,6 @@ void QXmppClient::setClientPresence(const QXmppPresence& presence)
     }
 }
 
-/// Adds the information about our client to the passed presence packet.
-/// Without this, the packet doesn't contain any information about
-/// client node string, capabilities, etc.
-///
-/// You generally should not need to call this function unless you craft
-/// the presence packets yourself and send them with the sendPacket()
-/// method.
-///
-/// \param presence
-
-void QXmppClient::addProperCapability(QXmppPresence &presence)
-{
-    d->addProperCapability(presence);
-}
-
 /// Function to get reconnection manager. By default there exists a reconnection
 /// manager. See QXmppReconnectionManager for more details of the reconnection
 /// mechanism.
