@@ -1,5 +1,5 @@
 /*
- * Copyright (C) 2008-2010 The QXmpp developers
+ * Copyright (C) 2008-2011 The QXmpp developers
  *
  * Author:
  *  Jeremy Lainé
@@ -210,7 +210,7 @@ void QXmppJingleIq::Content::toXml(QXmlStreamWriter *writer) const
     if (!m_descriptionType.isEmpty() || !m_payloadTypes.isEmpty())
     {
         writer->writeStartElement("description");
-        helperToXmlAddAttribute(writer, "xmlns", m_descriptionType);
+        writer->writeAttribute("xmlns", m_descriptionType);
         helperToXmlAddAttribute(writer, "media", m_descriptionMedia);
         foreach (const QXmppJinglePayloadType &payload, m_payloadTypes)
             payload.toXml(writer);
@@ -221,7 +221,7 @@ void QXmppJingleIq::Content::toXml(QXmlStreamWriter *writer) const
     if (!m_transportType.isEmpty() || !m_transportCandidates.isEmpty())
     {
         writer->writeStartElement("transport");
-        helperToXmlAddAttribute(writer, "xmlns", m_transportType);
+        writer->writeAttribute("xmlns", m_transportType);
         helperToXmlAddAttribute(writer, "ufrag", m_transportUser);
         helperToXmlAddAttribute(writer, "pwd", m_transportPassword);
         foreach (const QXmppJingleCandidate &candidate, m_transportCandidates)
@@ -281,46 +281,72 @@ void QXmppJingleIq::Reason::toXml(QXmlStreamWriter *writer) const
     writer->writeEndElement();
 }
 
+/// Constructs a QXmppJingleIq.
+
 QXmppJingleIq::QXmppJingleIq()
     : m_ringing(false)
 {
 }
 
+/// Returns the Jingle IQ's action.
+
 QXmppJingleIq::Action QXmppJingleIq::action() const
 {
     return m_action;
 }
 
+/// Sets the Jingle IQ's action.
+///
+/// \param action
+
 void QXmppJingleIq::setAction(QXmppJingleIq::Action action)
 {
     m_action = action;
 }
 
+/// Returns the session initiator.
+
 QString QXmppJingleIq::initiator() const
 {
     return m_initiator;
 }
 
+/// Sets the session initiator.
+///
+/// \param initiator
+
 void QXmppJingleIq::setInitiator(const QString &initiator)
 {
     m_initiator = initiator;
 }
 
+/// Returns the session responder.
+
 QString QXmppJingleIq::responder() const
 {
     return m_responder;
 }
 
+/// Sets the session responder.
+///
+/// \param responder
+
 void QXmppJingleIq::setResponder(const QString &responder)
 {
     m_responder = responder;
 }
 
+/// Returns the session ID.
+
 QString QXmppJingleIq::sid() const
 {
     return m_sid;
 }
 
+/// Sets the session ID.
+///
+/// \param sid
+
 void QXmppJingleIq::setSid(const QString &sid)
 {
     m_sid = sid;
@@ -332,11 +358,17 @@ bool QXmppJingleIq::isJingleIq(const QDomElement &element)
     return (jingleElement.namespaceURI() == ns_jingle);
 }
 
+/// Returns true if the call is ringing.
+
 bool QXmppJingleIq::ringing() const
 {
     return m_ringing;
 }
 
+/// Set to true if the call is ringing.
+///
+/// \param ringing
+
 void QXmppJingleIq::setRinging(bool ringing)
 {
     m_ringing = ringing;
@@ -372,7 +404,7 @@ void QXmppJingleIq::parseElementFromChild(const QDomElement &element)
 void QXmppJingleIq::toXmlElementFromChild(QXmlStreamWriter *writer) const
 {
     writer->writeStartElement("jingle");
-    helperToXmlAddAttribute(writer, "xmlns", ns_jingle);
+    writer->writeAttribute("xmlns", ns_jingle);
     helperToXmlAddAttribute(writer, "action", jingle_actions[m_action]);
     helperToXmlAddAttribute(writer, "initiator", m_initiator);
     helperToXmlAddAttribute(writer, "responder", m_responder);
@@ -384,7 +416,7 @@ void QXmppJingleIq::toXmlElementFromChild(QXmlStreamWriter *writer) const
     if (m_ringing)
     {
         writer->writeStartElement("ringing");
-        helperToXmlAddAttribute(writer, "xmlns", ns_jingle_rtp_info);
+        writer->writeAttribute("xmlns", ns_jingle_rtp_info);
         writer->writeEndElement();
     }
 
@@ -397,7 +429,8 @@ QXmppJingleCandidate::QXmppJingleCandidate()
     m_generation(0),
     m_network(0),
     m_port(0),
-    m_priority(0)
+    m_priority(0),
+    m_type(HostType)
 {
 }
 
@@ -538,7 +571,7 @@ void QXmppJingleCandidate::setProtocol(const QString &protocol)
 /// Returns the candidate type (e.g. "host").
 ///
 
-QString QXmppJingleCandidate::type() const
+QXmppJingleCandidate::Type QXmppJingleCandidate::type() const
 {
     return m_type;
 }
@@ -547,7 +580,7 @@ QString QXmppJingleCandidate::type() const
 ///
 /// \param type
 
-void QXmppJingleCandidate::setType(const QString &type)
+void QXmppJingleCandidate::setType(QXmppJingleCandidate::Type type)
 {
     m_type = type;
 }
@@ -571,7 +604,7 @@ void QXmppJingleCandidate::parse(const QDomElement &element)
     m_port = element.attribute("port").toInt();
     m_priority = element.attribute("priority").toInt();
     m_protocol = element.attribute("protocol");
-    m_type = element.attribute("type");
+    m_type = typeFromString(element.attribute("type"));
 }
 
 void QXmppJingleCandidate::toXml(QXmlStreamWriter *writer) const
@@ -586,10 +619,53 @@ void QXmppJingleCandidate::toXml(QXmlStreamWriter *writer) const
     helperToXmlAddAttribute(writer, "port", QString::number(m_port));
     helperToXmlAddAttribute(writer, "priority", QString::number(m_priority));
     helperToXmlAddAttribute(writer, "protocol", m_protocol);
-    helperToXmlAddAttribute(writer, "type", m_type);
+    helperToXmlAddAttribute(writer, "type", typeToString(m_type));
     writer->writeEndElement();
 }
 
+QXmppJingleCandidate::Type QXmppJingleCandidate::typeFromString(const QString &typeStr, bool *ok)
+{
+    QXmppJingleCandidate::Type type;
+    if (typeStr == "host")
+        type = HostType;
+    else if (typeStr == "prflx")
+        type = PeerReflexiveType;
+    else if (typeStr == "srflx")
+        type = ServerReflexiveType;
+    else if (typeStr == "relay")
+        type = RelayedType;
+    else {
+        qWarning() << "Unknown candidate type" << typeStr;
+        if (ok)
+            *ok = false;
+        return HostType;
+    }
+    if (ok)
+        *ok = true;
+    return type;
+}
+
+QString QXmppJingleCandidate::typeToString(QXmppJingleCandidate::Type type)
+{
+    QString typeStr;
+    switch (type)
+    {
+    case HostType:
+        typeStr = "host";
+        break;
+    case PeerReflexiveType:
+        typeStr = "prflx";
+        break;
+    case ServerReflexiveType:
+        typeStr = "srflx";
+        break;
+    case RelayedType:
+        typeStr = "relay";
+        break;
+    }
+    return typeStr;
+}
+
 QXmppJinglePayloadType::QXmppJinglePayloadType()
     : m_channels(1),
     m_clockrate(0),
@@ -729,6 +805,10 @@ void QXmppJinglePayloadType::toXml(QXmlStreamWriter *writer) const
     writer->writeEndElement();
 }
 
+/// Returns true if this QXmppJinglePayloadType and \a other refer to the same payload type.
+///
+/// \param other
+
 bool QXmppJinglePayloadType::operator==(const QXmppJinglePayloadType &other) const
 {
     // FIXME : what to do with m_ptime and m_maxptime?
